@@ -27,7 +27,7 @@ our @EXPORT_OK= qw( is_port_open
                     validate_json_object
                     ) ;
 
-our $VERSION="3.0.53";
+our $VERSION="3.0.54";
 our $DEBUG;
 
 BEGIN {
@@ -65,7 +65,7 @@ BEGIN {
 }
 
 my @supported_versions = qw( 3.23 4.0 4.1 5.0 5.1 5.2 5.3 5.4 
-    5.5 5.6 5.7 5.8 6.0 10.0);
+    5.5 5.6 5.7 5.8 6.0 10.0 10.1 );
 
 our $sandbox_options_file    = "my.sandbox.cnf";
 # our $sandbox_current_options = "current_options.conf";
