@@ -17,7 +17,7 @@ our @EXPORT_OK = qw(
     );
 our @EXPORT = @EXPORT_OK;
 
-our $VERSION="3.0.53";
+our $VERSION="3.0.54";
 
 our @MANIFEST = (
 'clear.sh',
@@ -43,6 +43,7 @@ our @MANIFEST = (
 'json_in_db.sh',
 '# INSTALL FILES',
 'sandbox_action.pl',
+'test_replication.sh',
 );
 
 #my $SBINSTR_SH_TEXT =<<'SBINSTR_SH_TEXT';
@@ -1912,6 +1913,115 @@ gearman =>    {
 
 PLUGIN_CONF
 
+    'test_replication.sh' => <<'TEST_REPLICATION',
+#!_BINBASH_
+__LICENSE__
+if [ -x ./m ]
+then
+    MASTER=./m
+elif [ -x ./n1 ]
+then
+    MASTER=./n1
+else
+    echo "# No master found"
+    exit 1
+fi
+$MASTER -e 'create schema if not exists test'
+$MASTER test -e 'drop table if exists t1'
+$MASTER test -e 'create table t1 (i int not null primary key, msg varchar(50), d date, t time, dt datetime, ts timestamp)'
+$MASTER test -e "insert into t1 values (1, 'test sandbox 1', '2015-07-16', '11:23:40','2015-07-17 12:34:50', null)"
+sleep 0.5
+$MASTER test -e "insert into t1 values (2, 'test sandbox 2', '2015-07-17', '11:23:41','2015-07-17 12:34:51', null)"
+MASTER_RECS=$($MASTER -BN -e 'select count(*) from test.t1')
+
+master_status=master_status$$
+slave_status=slave_status$$
+$MASTER -e 'show master status\G' > $master_status
+master_binlog=$(grep 'File:' $master_status | awk '{print $2}' )
+master_pos=$(grep 'Position:' $master_status | awk '{print $2}' )
+echo "# Master log: $master_binlog - Position: $master_pos - Rows: $MASTER_RECS"
+rm -f $master_status
+
+FAILED=0
+PASSED=0
+
+function ok_equal
+{
+    fact="$1"
+    expected="$2"
+    msg="$3"
+    if [ "$fact" == "$expected" ]
+    then
+        echo -n "ok"
+        PASSED=$(($PASSED+1))
+    else
+        echo -n "not ok - (expected: <$expected> found: <$fact>) "
+        FAILED=$(($FAILED+1))
+    fi
+    echo " - $msg"
+}
+
+function test_summary
+{
+    TESTS=$(($PASSED+$FAILED))
+    if [ -n "$TAP_TEST" ]
+    then
+        echo "1..$TESTS"
+    else
+        PERCENT_PASSED=$(($PASSED/$TESTS*100))
+        PERCENT_FAILED=$(($FAILED/$TESTS*100))
+        printf "# TESTS : %5d\n" $TESTS
+        printf "# FAILED: %5d (%5.1f%%)\n" $FAILED $PERCENT_FAILED
+        printf "# PASSED: %5d (%5.1f%%)\n" $PASSED $PERCENT_PASSED
+    fi
+}
+
+for SLAVE_N in 1 2 3 4 5 6 7 8 9
+do
+    N=$(($SLAVE_N+1)) 
+    unset SLAVE
+    if [ -x ./s$SLAVE_N ]
+    then
+        SLAVE=./s$SLAVE_N
+    elif [ -x ./n$N ]
+    then
+        SLAVE=./n$N
+    fi
+    if [ -n "$SLAVE" ]
+    then
+        echo "# Testing slave #$SLAVE_N"
+        if [ -f set_circular_replication.sh ]
+        then
+            sleep 3
+        else
+            S_READY=$($SLAVE -BN -e "select master_pos_wait('$master_binlog', $master_pos,60)")
+            # master_pos_wait can return 0 or a positive number for successful replication
+            # Any result that is not NULL or -1 is acceptable
+            if [ "$S_READY" != "-1" -a "$S_READY" != "NULL" ]
+            then
+                S_READY=0
+            fi
+            ok_equal $S_READY 0 "Slave #$SLAVE_N acknowledged reception of transactions from master" 
+        fi
+        $SLAVE -e 'show slave status\G' > $slave_status
+        IO_RUNNING=$(grep -w Slave_IO_Running $slave_status | awk '{print $2}')
+        ok_equal $IO_RUNNING Yes "Slave #$SLAVE_N IO thread is running"
+        SQL_RUNNING=$(grep -w Slave_IO_Running $slave_status | awk '{print $2}')
+        ok_equal $SQL_RUNNING Yes "Slave #$SLAVE_N SQL thread is running"
+        rm -f $slave_status 
+
+        [ $FAILED == 0 ] || exit 1
+
+        T1_EXISTS=$($SLAVE -BN -e 'show tables from test like "t1"')
+        ok_equal $T1_EXISTS t1 "Table t1 found on slave #$SLAVE_N"
+        T1_RECS=$($SLAVE -BN -e 'select count(*) from test.t1')
+        ok_equal $T1_RECS $MASTER_RECS "Table t1 has $MASTER_RECS rows on #$SLAVE_N"
+    fi
+done
+test_summary
+
+TEST_REPLICATION
+
 );
 
 # --- END SCRIPTS IN CODE ---
